library(tidyverse)
library(brms)
library(HDInterval)

############################################
## options for Bayesian regression with Stan
############################################

# set cores to use to the total number of cores
options(mc.cores = parallel::detectCores()) 

##################################################
## helper function for Bayesian credible intervals
##################################################

hdi_vec = function(alpha, beta) {
  hdi(qbeta, shape1 = alpha, shape2 = beta) # requires package "HDInterval"
}

######################
## read and clean data
######################

# all paths relative to base folder of repo
d = read_csv("IRU_pilot_raw_data.csv") %>% 
  filter(submission_id != 549) # remove MF's test trial

# any double takers?
double_takers = which(table(d$prolific_id) > 6) %>% names()
d = d %>% filter(! prolific_id %in%  double_takers) # remove double takers

# any non-English?
d$languages %>% table() %>% names()
d = d %>% filter(! languages == "Danish") # remove Danish speaker

paste0(d$submission_id %>% 
         as.factor() %>% 
         nlevels(), 
       " participants remaining after basic data cleaning")

# prepare for analysis
d = d %>% filter(inference_type != "filler") %>%
  mutate(response = ifelse(response == "imp", 1, 0),
         inference_type = factor(inference_type),
         condition = factor(condition))

#####################
## summarize and plot
#####################

d_sum = d %>% 
  mutate(inference_type = factor(
    inference_type, 
    ordered = T, 
    levels = c("scalar", "iru", "manner"))
    ) %>% 
  group_by(inference_type, condition) %>% 
  summarize(lower = hdi_vec(sum(response)+1, 
                            n()-sum(response)+1)[1],
            mean_imp = mean(response),
            upper = hdi_vec(sum(response)+1, 
                            n()-sum(response)+1)[2])  
  
  
d_sum %>% ggplot(aes(x = condition, y = mean_imp)) + 
  geom_bar(stat="identity", fill = "skyblue") + 
  geom_errorbar(aes(ymin = lower, ymax = upper), 
                color = "darkblue", 
                width = .25, size = 0.15) +
  coord_flip() +
  ylab("proportion of TRUE responses") +
  facet_wrap(.~inference_type) 

#######################################
## regression model; only fixed effects
#######################################

# run model
model = brm(response ~ condition * inference_type, 
            data = d, 
            family = bernoulli(link = "logit"),
            control = list(max_treedepth = 15),
            iter = 3000)

  # get posterior samples
samples = posterior_samples(model)

# get mnemonic labels for samples

iru_plain = samples$b_Intercept
iru_redundant = samples$b_conditionredundant
iru_wordy = samples$b_conditionwordy

manner_plain = samples$b_Intercept + samples$b_inference_typemanner
manner_redundant = samples$b_conditionredundant + samples$b_inference_typemanner + samples$`b_conditionredundant:inference_typemanner`
manner_wordy = samples$b_conditionwordy + samples$b_inference_typemanner + samples$`b_conditionwordy:inference_typemanner`

scalar_plain = samples$b_Intercept + samples$b_inference_typescalar
scalar_redundant = samples$b_conditionredundant + samples$b_inference_typescalar + samples$`b_conditionredundant:inference_typescalar`
scalar_wordy = samples$b_conditionwordy + samples$b_inference_typescalar + samples$`b_conditionwordy:inference_typescalar`

# calculate pairwise differences from samples

comparisons = tibble(
  condition = rep(c("scalar", "iru", "manner"), each = 3),
  comparison = rep(c("plain > wordy", "plain > redundant", "wordy > redundant"), times = 3),
  degree_of_belief = c(
    # scalar
    mean(scalar_plain > scalar_wordy),
    mean(scalar_plain > scalar_redundant),
    mean(scalar_wordy > scalar_redundant),
    # iru
    mean(iru_plain > iru_wordy),
    mean(iru_plain > iru_redundant),
    mean(iru_wordy > iru_redundant),
    # manner
    mean(manner_plain > manner_wordy),
    mean(manner_plain > manner_redundant),
    mean(manner_wordy > manner_redundant)
  ),
  credibly_different = ifelse((degree_of_belief < 0.05 | degree_of_belief > 0.95), "*", "-")
)

show(comparisons)
